@@ -1,6 +1,7 @@
 import math
 import torch
 import torch.nn as nn
+from torch.nn import Identity
 import torch.nn.functional as F
 from torch.autograd import Function
 from functools import partial, reduce
@@ -56,10 +57,6 @@ def max_neg_value(tensor):
 
 # helper classes
 
-class Identity(nn.Module):
-    def forward(self, x):
-        return x
-
 class MatrixMultiply(nn.Module):
     def __init__(self, tensor, transpose = False, normalize = False):
         super().__init__()
